@@ -6,12 +6,14 @@ import shutil, os
 
 class EESConnector:
 
-    def __init__(self, ees_file_path=None, keep_refprop=False):
+    def __init__(self, ees_file_path=None, keep_refprop=False, solve_with_macro=False):
 
         self.__clear_files()
+
+        self.__ees_file_path = None
         self.__with_initialization = False
         self.__keep_refprop = keep_refprop
-        self.__ees_file_path = None
+        self.__solve_with_macro = solve_with_macro
 
         if ees_file_path is not None:
             self.ees_file_path = ees_file_path
@@ -19,7 +21,7 @@ class EESConnector:
     def __enter__(self):
 
         self.__with_initialization = True
-        self.__move_REFPROP_DIR(move_away=True)
+        self.move_REFPROP_DIR(move_away=True)
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
@@ -30,75 +32,22 @@ class EESConnector:
 
         if self.is_ready:
 
-            self.__prepare_input(input_list)
+            if self.__solve_with_macro:
 
-        try:
+                return self.__calculate_with_macro(input_list)
 
-            system_comand = "{} {}".format(constants.EES_PATH, constants.EES_MACRO)
-            os.chdir(constants.WORKSPACE_DIR)
-            os.system(system_comand)
+            else:
 
-        except:
-
-            return None
-
-        else:
-
-            return self.__collect_output()
+                return self.__calculate_directly(input_list)
 
     def quit(self):
 
-        self.__move_REFPROP_DIR(move_away=False)
+        self.move_REFPROP_DIR(move_away=False)
         if self.is_ready:
             # This part delete the file used for data IO
             self.__clear_files()
 
-    def __prepare_input(self, input_list):
-
-        if type(input_list) == list:
-
-            self.__write_input_file(input_list, "default")
-            last_file_path = os.path.join(constants.WORKSPACE_DIR, "default" + constants.IO_FILE_EXTENSION)
-
-        elif type(input_list) == dict:
-
-            key = "1"
-            for key in input_list.keys():
-
-                self.__write_input_file(input_list[key], key)
-
-            last_file_path = os.path.join(constants.WORKSPACE_DIR, key + constants.IO_FILE_EXTENSION)
-
-        else:
-            return
-
-        shutil.copy(last_file_path, os.path.join(constants.WORKSPACE_DIR, constants.EES_INPUT_FILENAME))
-
-    def __collect_output(self):
-
-        return_dict = dict()
-
-        for file in os.listdir(constants.WORKSPACE_DIR):
-
-            if file.endswith(constants.IO_FILE_EXTENSION):
-
-                key = file.strip(constants.IO_FILE_EXTENSION)
-
-                return_dict.update({
-
-                    key: self.__read_output_file(key)
-
-                })
-
-        if "default" in return_dict.keys():
-
-            return return_dict["default"]
-
-        else:
-
-            return return_dict
-
-    def __move_REFPROP_DIR(self, move_away):
+    def move_REFPROP_DIR(self, move_away=True):
 
         if move_away:
 
@@ -114,6 +63,122 @@ class EESConnector:
                 # restore the plugin functionality
                 shutil.move(constants.EES_REFPROP_TMP_DIR, constants.EES_REFPROP_DIR)
 
+    def __calculate_directly(self, input_list):
+
+        if type(input_list) == list:
+
+            return self.__direct_calculation_passage(input_list)
+
+        elif type(input_list) == dict:
+
+            return_dict = dict()
+
+            for key in input_list.keys():
+
+                print("Calculating: " + key)
+
+                return_dict.update({
+
+                    key: self.__direct_calculation_passage(input_list[key])
+
+                })
+
+            return return_dict
+
+        else:
+
+            return None
+
+    def __direct_calculation_passage(self, input_list):
+
+        filename = os.path.join(constants.WORKSPACE_DIR, "ees_input.dat")
+        self.__write_input_file(input_list, filename)
+
+        try:
+
+            system_comand = "{} {} /solve /hide".format(constants.EES_PATH, constants.EES_RUN_FILENAME)
+            os.chdir(constants.WORKSPACE_DIR)
+            os.system(system_comand)
+
+        except:
+
+            return None
+
+        else:
+
+            filename = os.path.join(constants.WORKSPACE_DIR, "ees_output.dat")
+            return self.__read_output_file(filename)
+
+    def __calculate_with_macro(self, input_list):
+
+        if len(input_list) == 1:
+
+            return self.__calculate_directly(input_list)
+
+        else:
+
+            self.__prepare_macro_input(input_list)
+
+            try:
+
+                system_comand = "{} {} /hide".format(constants.EES_PATH, constants.EES_MACRO)
+                os.chdir(constants.WORKSPACE_DIR)
+                os.system(system_comand)
+
+            except:
+
+                return None
+
+            else:
+
+                return self.__collect_macro_output()
+
+    def __prepare_macro_input(self, input_list):
+
+        if type(input_list) == list:
+
+            filename = os.path.join(constants.WORKSPACE_DIR, "default" + constants.IO_FILE_EXTENSION)
+            self.__write_input_file(input_list, filename)
+
+        elif type(input_list) == dict:
+
+            filename = os.path.join(constants.WORKSPACE_DIR, "1" + constants.IO_FILE_EXTENSION)
+            for key in input_list.keys():
+                filename = os.path.join(constants.WORKSPACE_DIR, key + constants.IO_FILE_EXTENSION)
+                self.__write_input_file(input_list[key], filename)
+
+        else:
+            return
+
+        shutil.copy(filename, os.path.join(constants.WORKSPACE_DIR, constants.EES_INPUT_FILENAME))
+
+    def __collect_macro_output(self):
+
+        return_dict = dict()
+
+        for file in os.listdir(constants.WORKSPACE_DIR):
+
+            if file.endswith(constants.IO_FILE_EXTENSION):
+
+                filename = os.path.join(constants.WORKSPACE_DIR, file)
+                key = file.strip(constants.IO_FILE_EXTENSION)
+
+                return_dict.update({
+
+                    key: self.__read_output_file(filename)
+
+                })
+
+        self.__clear_files()
+
+        if "default" in return_dict.keys():
+
+            return return_dict["default"]
+
+        else:
+
+            return return_dict
+
     @staticmethod
     def __write_input_file(input_list, filename):
 
@@ -122,14 +187,15 @@ class EESConnector:
         for element in input_list[1:]:
             string_to_write += "\t" + str(element)
 
-        string_to_write.replace(".", ",")
-        with open(os.path.join(constants.WORKSPACE_DIR, filename + constants.IO_FILE_EXTENSION), "w") as f:
+        string_to_write = string_to_write.replace(".", ",")
+
+        with open(filename, "w") as f:
             f.write(string_to_write)
 
     @staticmethod
     def __read_output_file(filename):
 
-        with open(os.path.join(constants.WORKSPACE_DIR, filename + constants.IO_FILE_EXTENSION), "r") as f:
+        with open(filename, "r") as f:
 
             lines = f.readlines()
 
@@ -191,23 +257,51 @@ class EESConnector:
 
         constants.retrieve_EES_path()
 
+    @classmethod
+    def modify_macro_delay(cls, delay_ms):
+
+        constants.set_macro(delay_ms)
+
 
 if __name__ == "__main__":
 
-    with EESConnector() as connector:
+    import time
+
+    n_calculations = 32
+    calculate_with_macro = True
+    input_dict = dict()
+
+    T_amb = 15
+    T_BHE_in = 30
+    T_BHE_out = 100
+    P_BHE_in = 8000
+    P_BHE_out = 15000
+    steam_production = 1
+    P_steam = 1000
+    P_SG_perc = 0.5
+    dT_SG_pinch = 10
+
+    for i in range(n_calculations):
+
+        P_SG_perc = (float(i) / n_calculations) * (0.7 - 0.2) + 0.2
+
+        input_dict.update({
+
+            str(P_SG_perc): [
+
+                "CarbonDioxide", T_amb,
+                T_BHE_in, T_BHE_out, P_BHE_in, P_BHE_out,
+                steam_production, P_steam, P_SG_perc, dT_SG_pinch
+
+            ]
+
+        })
+
+    with EESConnector(solve_with_macro=calculate_with_macro) as connector:
 
         connector.select_file()
-        # result = connector.calculate({
-        #
-        #     "1": ["air_ha", 300, 1013.25],
-        #     "2": ["R22", 300, 1013.25],
-        #     "3": ["R236fa", 300, 1013.25],
-        #     "4": ["R134a", 300, 1013.25],
-        #     "5": ["R236fa", 300, 1013.25],
-        #     "6": ["R134a", 300, 1013.25],
-        #     "7": ["R236fa", 300, 1013.25],
-        #     "8": ["R134a", 300, 1013.25]
-        #
-        # })
-        result = connector.calculate(["air_ha", 300, 1013.25])
-        print(result)
\ No newline at end of file
+        start = time.time()
+        result = connector.calculate(input_dict)
+        print(result)
+
+    print("\n\ttime elapsed = {} s\n".format(time.time() - start))
\ No newline at end of file
